@@ -70,8 +70,8 @@ from orangecontrib.shadow_advanced_tools.util.gui import PowerPlotXYWidget
 
 class PowerPlotXY(AutomaticElement):
 
-    name = "Power Plot XY"
-    description = "Display Data Tools: Power Plot XY"
+    name = "Power Plot XY - Undulator"
+    description = "Display Data Tools: Power Plot XY - Undulator"
     icon = "icons/plot_xy_power.png"
     maintainer = "Luca Rebuffi"
     maintainer_email = "lrebuffi(@at@)anl.gov"
